netapp_ontap.resources.dns API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.dns`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

Displays DNS information and controls the DNS subsytem. DNS domain name and DNS servers are required parameters.

## Retrieving DNS information

The DNS GET endpoint retrieves all of the DNS configurations for data SVMs. DNS configuration for the cluster is retrieved via `/api/cluster`.

## Examples

### Retrieving all of the fields for all of the DNS configurations

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Dns

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Dns.get_collection(fields="*")))

Try it out

    [
        Dns(
            {
                "servers": ["10.10.10.10"],
                "domains": ["domainA.example.com"],
                "_links": {
                    "self": {
                        "href": "/api/name-services/dns/179d3c85-7053-11e8-b9b8-005056b41bd1"
                    }
                },
                "svm": {
                    "name": "vs1",
                    "uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/179d3c85-7053-11e8-b9b8-005056b41bd1"
                        }
                    },
                },
            }
        ),
        Dns(
            {
                "servers": ["11.11.11.11", "22.22.22.22", "33.33.33.33"],
                "domains": ["sample.example.com"],
                "_links": {
                    "self": {
                        "href": "/api/name-services/dns/19076d35-6e27-11e8-b9b8-005056b41bd1"
                    }
                },
                "svm": {
                    "name": "vs2",
                    "uuid": "19076d35-6e27-11e8-b9b8-005056b41bd1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/19076d35-6e27-11e8-b9b8-005056b41bd1"
                        }
                    },
                },
            }
        ),
    ]

### Retrieving all DNS configurations whose domain name starts with dom*.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Dns

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Dns.get_collection(domains="dom*")))

Try it out

    [
        Dns(
            {
                "domains": ["domainA.example.com"],
                "_links": {
                    "self": {
                        "href": "/api/name-services/dns/179d3c85-7053-11e8-b9b8-005056b41bd1"
                    }
                },
                "svm": {
                    "name": "vs1",
                    "uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/179d3c85-7053-11e8-b9b8-005056b41bd1"
                        }
                    },
                },
            }
        )
    ]

### Retrieving the DNS configuration for a specific SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Dns

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Dns(**{"svm.uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"})
        resource.get()
        print(resource)

Try it out

    Dns(
        {
            "servers": ["10.10.10.10"],
            "domains": ["domainA.example.com"],
            "_links": {
                "self": {
                    "href": "/api/name-services/dns/179d3c85-7053-11e8-b9b8-005056b41bd1"
                }
            },
            "svm": {
                "name": "vs1",
                "uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1",
                "_links": {
                    "self": {"href": "/api/svm/svms/179d3c85-7053-11e8-b9b8-005056b41bd1"}
                },
            },
        }
    )

## Creating a DNS configuration

The DNS POST endpoint creates a DNS configuration for the specified SVM.

## Example

The following example shows a POST operation:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Dns

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Dns()
        resource.svm.uuid = "179d3c85-7053-11e8-b9b8-005056b41bd1"
        resource.domains = ["domainA.example.com"]
        resource.servers = ["10.10.10.10"]
        resource.post(hydrate=True)
        print(resource)

## Updating a DNS configuration

The DNS PATCH endpoint updates the DNS configuration for the specified SVM.

## Examples

### Updating both the DNS domains and servers

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Dns

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Dns(**{"svm.uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"})
        resource.domains = ["domainA.example.com", "domainB.example.com"]
        resource.servers = ["10.10.10.10", "10.10.10.11"]
        resource.patch()

### Updating the DNS servers only

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Dns

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Dns(**{"svm.uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"})
        resource.servers = ["10.10.10.10"]
        resource.patch()

## Deleting a DNS configuration

The DNS DELETE endpoint deletes the DNS configuration for the specified SVM.

## Example

The following example shows a DELETE operation.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Dns

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Dns(**{"svm.uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"})
        resource.delete()

## Classes

`class Dns (*args, **kwargs)`

  Allows interaction with Dns objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the DNS configurations of all data SVMs. DNS configuration for the cluster is retrieved and managed via `/api/cluster`.

    ### Related ONTAP commands

    - `vserver services name-service dns show`
    - `vserver services name-service dns check`

    ### Learn more

    - `DOC /name-services/dns`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes DNS domain configuration of the specified SVM.

    ### Related ONTAP commands

    - `vserver services name-service dns delete`

    ### Learn more

    - `DOC /name-services/dns`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the DNS configurations of all data SVMs. DNS configuration for the cluster is retrieved and managed via `/api/cluster`.

    ### Related ONTAP commands

    - `vserver services name-service dns show`
    - `vserver services name-service dns check`

    ### Learn more

    - `DOC /name-services/dns`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the DNS configurations of all data SVMs. DNS configuration for the cluster is retrieved and managed via `/api/cluster`.

    ### Related ONTAP commands

    - `vserver services name-service dns show`
    - `vserver services name-service dns check`

    ### Learn more

    - `DOC /name-services/dns`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates DNS domain and server configurations of an SVM.

    ### Important notes

    - Both DNS domains and servers can be modified.
    - The domains and servers fields cannot be empty.
    - IPv6 must be enabled if IPv6 family addresses are specified for the `servers` field.
    - The DNS server specified using the `servers` field is validated during this operation.
      The validation fails in the following scenarios:
    - The server is not a DNS server.
    - The server does not exist.
    - The server is unreachable.

    ### Learn more

    - `DOC /name-services/dns`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes DNS domain configuration of the specified SVM.

    ### Related ONTAP commands

    - `vserver services name-service dns delete`

    ### Learn more

    - `DOC /name-services/dns`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves DNS domain and server configuration of an SVM. By default, both DNS domains and servers are displayed. DNS configuration for the cluster is retrieved and managed via `/api/cluster`.

    ### Related ONTAP commands

    - `vserver services name-service dns show`
    - `vserver services name-service dns check`

    ### Learn more

    - `DOC /name-services/dns`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates DNS domain and server configurations of an SVM.

    ### Important notes

    - Both DNS domains and servers can be modified.
    - The domains and servers fields cannot be empty.
    - IPv6 must be enabled if IPv6 family addresses are specified for the `servers` field.
    - The DNS server specified using the `servers` field is validated during this operation.
      The validation fails in the following scenarios:
    - The server is not a DNS server.
    - The server does not exist.
    - The server is unreachable.

    ### Learn more

    - `DOC /name-services/dns`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates DNS domain and server configurations for an SVM.

    ### Important notes

    - Each SVM can have only one DNS configuration.
    - The domain name and the servers fields cannot be empty.
    - IPv6 must be enabled if IPv6 family addresses are specified in the `servers` field.
    - Configuring more than one DNS server is recommended to avoid a single point of failure.
    - The DNS server specified using the `servers` field is validated during this operation.
      The validation fails in the following scenarios:
    - The server is not a DNS server.
    - The server does not exist.
    - The server is unreachable.

    ### Learn more

    - `DOC /name-services/dns`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class DnsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Dns object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `domains GET POST PATCH`

    The domains field of the dns.

  `links GET`

    The links field of the dns.

  `servers GET POST PATCH`

    The servers field of the dns.

  `svm GET POST PATCH`

    The svm field of the dns.